# SpikeForest

This python package is at a very prelim stage and will experience breaking changes on a daily basis. For information on the overall project, [please see these docs](https://users.flatironinstitute.org/~magland/docs/).
